@@ -4,7 +4,7 @@ from django.core.mail import send_mail
 from django.core.context_processors import csrf
 from indeed_contactForm.models import Message
 from indeed_contactForm.forms import ContactForm
-from settings import EMAIL_CONTACT
+from django.conf.settings import EMAIL_CONTACT
 import datetime
 
 
